﻿using Microsoft.EntityFrameworkCore;
using UserManager.Application.Interfaces;

namespace UserManager.Infrastructure
{
    public class BaseRepository<TEntity>(UserManagerContext context) : IBaseRepository<TEntity> where TEntity : class
    {
        private readonly DbSet<TEntity> _dbSet = context.Set<TEntity>();

        public async Task<TEntity?> GetByIdAsync(object?[]? id)
        {
            return await _dbSet.FindAsync(id);
        }
        
        public async Task CreateAsync(TEntity entity)
        {
            await _dbSet.AddAsync(entity);
        }
        
        public void Update(TEntity entity)
        {
            _dbSet.Attach(entity);
            context.Entry(entity).State = EntityState.Modified;
        }
        
        public void Delete(TEntity entity)
        {
            _dbSet.Attach(entity);
            context.Entry(entity).State = EntityState.Deleted;
        }

        public async Task DeleteAsync(object?[]? id)
        {
            TEntity? entity = await GetByIdAsync(id);
            
            if (entity != null)
            {
                Delete(entity);
            }
        }
    }
}
